@@ -1,5 +1,4 @@
 from .keyboardinputconverter import KeyboardInputConverter
-from .interfacetype import InterfaceType
 from .treeitems import TreeItems
+from .treeitemaction import TreeItemAction
 from .treeitemsparser import TreeItemsParser
-from .util import *
