@@ -1,6 +1,7 @@
 from robotlibcore import keyword
 from FlaUILibrary.flaui.interface import InterfaceType
 from FlaUILibrary.flaui.module import Grid
+from FlaUILibrary.flaui.uia import UIA
 
 
 class GridKeywords:
@@ -8,7 +9,7 @@ class GridKeywords:
     Interface implementation from robotframework usage for grid keywords.
     """
 
-    def __init__(self, module):
+    def __init__(self, module: UIA):
         """
         Constructor for list view keywords.
 
